Recipes
============

Recipes are simple guides to solving common problems that occur when creating
ecommerce projects.

.. toctree::
   :maxdepth: 2

   recipes/custom_shipping_logic
   recipes/enforcing_stock_rules
